@@ -2,6 +2,7 @@ from .api import *
 from .data import *
 from .models import *
 from .trainer import *
+from .pipeline import *
 from .protocol import *
 from .inference import *
 from .configs import Configs
@@ -12,6 +13,7 @@ from .modules.heads import HeadBase
 from .modules.heads import HeadConfigs
 from .modules.extractors import ExtractorBase
 from .modules.aggregators import AggregatorBase
+from .external_ import *
 
 from pkg_resources import get_distribution
 
