@@ -18,6 +18,7 @@ from cfdata.tabular import task_type_type
 from cfdata.tabular import parse_task_type
 from cfdata.tabular import TaskTypes
 
+from ..dist import inject_distributed_tqdm_kwargs
 from ..dist import Task
 from ..dist import Experiment
 from ..dist import ExperimentResults
@@ -28,6 +29,7 @@ from ..trainer import Trainer
 from ..trainer import TrainerCallback
 from ..trainer import IntermediateResults
 from ..pipeline import Pipeline
+from ..pipeline import ExternalPipelineProtocol
 from ..protocol import DataProtocol
 from ..misc._api import _to_saving_path
 from ..misc._api import _make_saving_path
@@ -50,6 +52,18 @@ def make(
     return Pipeline.make(parsed_config, parsed_increment_config)
 
 
+def make_external(
+    protocol: ExternalPipelineProtocol,
+    config: general_config_type = None,
+    increment_config: general_config_type = None,
+    **kwargs: Any,
+) -> Pipeline:
+    m = make("", config, increment_config, **kwargs)
+    m.custom_fit = protocol.fit
+    m.custom_predict = protocol.predict  # type: ignore
+    return m
+
+
 class _PipeConfigManager:
     def __init__(
         self,
@@ -447,7 +461,7 @@ def repeat_with(
     pipelines_dict: Optional[Dict[str, List[Pipeline]]] = None
     if sequential:
         experiment = None
-        kwargs["use_tqdm"] = False
+        kwargs["tqdm_position"] = 2
         if not return_patterns:
             print(
                 f"{LoggingMixin.warning_prefix}`return_patterns` should be "
@@ -496,6 +510,7 @@ def repeat_with(
         for model in models:
             for i in range(num_repeat):
                 local_config = fetch_config(i, model)
+                inject_distributed_tqdm_kwargs(i, num_jobs, local_config)
                 experiment.add_task(
                     model=model,
                     compress=compress,
@@ -584,6 +599,7 @@ def switch_trainer_callback(callback_base: Type[TrainerCallback]) -> None:
 
 __all__ = [
     "make",
+    "make_external",
     "ModelConfig",
     "make_from",
     "finetune",
@@ -592,6 +608,7 @@ __all__ = [
     "evaluate",
     "task_loader",
     "load_experiment_results",
+    "inject_distributed_tqdm_kwargs",
     "repeat_with",
     "make_toy_model",
     "switch_trainer_callback",
