@@ -22,6 +22,7 @@ predictor_type = Optional[Callable[[int, TabularDataset, np.ndarray], np.ndarray
 evaluator_type = Optional[Callable[[List[np.ndarray], List[np.ndarray]], np.ndarray]]
 prefetch_batch_type = Tuple[tensor_dict_type, Optional[torch.Tensor]]
 loader_batch_type = Union[tensor_dict_type, prefetch_batch_type]
+losses_type = Union[torch.Tensor, tensor_dict_type]
 
 
 __all__ = [
@@ -35,4 +36,5 @@ __all__ = [
     "evaluator_type",
     "prefetch_batch_type",
     "loader_batch_type",
+    "losses_type",
 ]
